@@ -7,7 +7,7 @@ from boto3.dynamodb.conditions import Key, Attr
 from botocore.exceptions import ClientError
 
 from properly_util_python.dynamo_helper import DynamoHelperBase, EnvironmentControlledDynamoHelper
-from properly_util_python.helper_utils import dynamo_to_dict
+from properly_util_python.helper_utils import dynamo_to_dict, dict_to_dynamo
 
 
 def save_to_dynamo(table_name, item: dict, dynamodb_helper: DynamoHelperBase = EnvironmentControlledDynamoHelper(),
@@ -38,25 +38,6 @@ def save_to_dynamo(table_name, item: dict, dynamodb_helper: DynamoHelperBase = E
     return response
 
 
-def dict_to_dynamo(raw_dict):
-    dynamo_dict = {}
-
-    # print(json.dumps(raw_dict, indent=4))
-    for key, val in raw_dict.items():
-        if isinstance(val, float):
-            dynamo_dict[key] = decimal.Decimal(str(val))
-        elif isinstance(val, dict):
-            dynamo_dict[key] = dict_to_dynamo(raw_dict[key])
-
-        # turn empty strings to null
-        elif val == 0:
-            dynamo_dict[key] = decimal.Decimal('0')
-        elif not val:
-            dynamo_dict[key] = None
-        else:
-            dynamo_dict[key] = val
-    return dynamo_dict
-
 
 def add_dynamo_metadata(data):
     data['dynamoUploadTimeStamp'] = int(round(time.time() * 1000))
@@ -192,6 +173,38 @@ def set_last_key(last_eval_config, table_name, val, META_KEY_MAP,
     meta_table.put_item(Item=config_object)
 
 
+
+
+# Update 2018 07 24 : TODO:
+# As of 0.10.48 of properly-util-python there is a utility library for accessing this
+# Craig is not updating the calling code below as it is not currently covered in tests, but,
+# this is a reminder to Craig or any others that the the next meaningful change
+# and test in this area should consider replacing the code below with:
+#
+# from properly_util_python.distributed_property import DistributedPropertyTuple
+#
+#  ...
+# self.last_key_config = DistributedPropertyTuple(property_id="4oH5qF2QiU2M3_ZNygpVMQ",
+#                                                         short_name="LAST_PROCESSED_HISTORICAL_RAW_FOR_CLEANING",
+#                                                         long_description="Last evaluated key of the historical-raw table so that multiple cleaners can cooperate on different parts of the table",
+#                                                         dynamo_helper=EnvironmentControlledDynamoHelper())
+#
+# ...
+#
+# last_evaluated = response.get('LastEvaluatedKey', None)
+# self.last_key_config.set_property(last_evaluated)
+#
+
+#####
+# Update 2018 07 27
+#
+# This code is duplicated around in a number of places and shouldn't be, for now just trying to remove other places.
+#
+# Additionally should review the encapsulating boundary (call api seems wide)
+# Still not fully removed
+
+
+
 #############
 # Query for next set of items
 
@@ -234,7 +247,8 @@ def scan_some_items(table_name, META_CONFIG, META_KEY_MAP, limit=20,
     last_evaluated = get_last_key(META_CONFIG[META_KEY_MAP["META_ID"]], meta_table_name, META_KEY_MAP)
     table = dynamodb_helper.get_dynamo_db().Table(table_name)
 
-    # performance improved by querying for the reserved value, no retries, if throughput exceeded will pick up next time
+    # scan should almost never be used, if you are calling this know the performance behavior
+    # https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/bp-query-scan.html
     if last_evaluated:
         response = table.scan(
             Limit=limit,
